import { dirname, join } from 'path';
import { fileURLToPath } from 'url';
import fs from 'fs-extra';
import {
  EDGE_FUNCTION_DIR,
  EDGE_FUNCTION_FILE,
  METADATA_FILE,
  STORIES_FILE,
} from '../constants.js';

export const generateFunctions = async ({
  constants: { EDGE_FUNCTIONS_SRC: dest = join('netlify', EDGE_FUNCTION_DIR) },
  netlifyConfig,
  utils: { build },
}) => {
  try {
    const __dirname = dirname(fileURLToPath(import.meta.url));
    const src = join(__dirname, '..', '..', EDGE_FUNCTION_DIR);

    /* eslint-disable import/no-named-as-default-member */
    await fs.ensureDir(dest);
    await fs.copy(src, dest);
    /* eslint-enable import/no-named-as-default-member */

    netlifyConfig.edge_functions = [
      ...(netlifyConfig.edge_functions || []),
      ...[METADATA_FILE, STORIES_FILE].map((file) => ({
        path: `/${file}.json`,
        function: EDGE_FUNCTION_FILE,
      })),
    ];
  } catch (error) {
    build.failPlugin('Failed to generate edge functions', {
      error,
    });
  }
};
