import { join } from 'path';
import fs from 'fs-extra';
import { METADATA_FILE, STORIES_FILE } from '../constants.js';

const fileName = (name) => [name, '.json'].join('');

export const generateMetadata = async ({
  constants: { PUBLISH_DIR: dest },
  packageJson,
  utils: { build },
}) => {
  const { version } = packageJson;
  const url = process.env.DEPLOY_URL;

  if (!version || !url) return null;

  const metadata = { versions: { [`v${version}`]: url } };
  const file = fileName(METADATA_FILE);

  try {
    // eslint-disable-next-line import/no-named-as-default-member
    await fs.writeJSON(join(dest, file), metadata);

    console.log(`Generated ${file}`);
  } catch (error) {
    build.failPlugin(`Failed to generate ${file}`, { error });
  }
};

export const generateStories = async ({
  constants: { PUBLISH_DIR: dest },
  utils: { build, run },
}) => {
  const file = fileName(STORIES_FILE);

  try {
    // eslint-disable-next-line import/no-named-as-default-member
    await fs.access(join(dest, file));
    console.log(`Existing ${file} found`);
  } catch {
    try {
      await run.command(`npx sb extract ${dest}`);
      console.log(`Generated ${file}`);
    } catch (error) {
      build.failPlugin(`Failed to generate ${file}`, { error });
    }
  }
};
